@@ -1,30 +1,38 @@
-/* -*- c-file-style: "ruby" -*- */
+/* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- * Ruby/GIO: a Ruby binding of gio-2.0.x.
- * Copyright (C) 2008-2009  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2008-2009  Ruby-GNOME2 Project Team
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
-#include "gio2.h"
+#include "rbgio2private.h"
+
+
+#ifndef HAVE_RB_ERRINFO
+#  define rb_errinfo() (ruby_errinfo)
+#endif
+
 
 static ID s_id_enum_name;
 static ID s_id_errors;
 
 static VALUE s_errors;
 
+
 VALUE
 rbgio_cstr_to_rval_tainted(const char *string, gsize length)
 {
@@ -117,23 +125,45 @@ rbgio_fds_to_ary_free(gint *fds)
                          rbgio_fds_to_ary_free_ensure, (VALUE)fds);
 }
 
-GList *
-rbgio_gfile_ary_to_glist(VALUE ary)
+struct rbgio_gfile_ary_to_glist_args {
+    VALUE ary;
+    long n;
+    GList *result;
+};
+
+static VALUE
+rbgio_gfile_ary_to_glist_body(VALUE value)
 {
-        int i, n;
-        volatile GFile *file;
-        GList *list = NULL;
+    long i;
+    struct rbgio_gfile_ary_to_glist_args *args = (struct rbgio_gfile_ary_to_glist_args *)value;
 
-        ary = rb_ary_to_ary(ary);
-        n = RARRAY_LEN(ary);
+    for (i = 0; i < args->n; i++)
+            args->result = g_list_append(args->result, RVAL2GFILE(RARRAY_PTR(args->ary)[i]));
 
-        for (i = 0; i < n; i++)
-                file = RVAL2GFILE(RARRAY_PTR(ary)[i]);
+    return Qnil;
+}
 
-        for (i = 0; i < n; i++)
-                list = g_list_append(list, RVAL2GFILE(RARRAY_PTR(ary)[i]));
+static G_GNUC_NORETURN VALUE
+rbgio_gfile_ary_to_glist_rescue(VALUE value)
+{
+    g_list_free(((struct rbgio_gfile_ary_to_glist_args *)value)->result);
 
-        return list;
+    rb_exc_raise(rb_errinfo());
+}
+
+GList *
+rbgio_gfile_ary_to_glist(VALUE value)
+{
+    struct rbgio_gfile_ary_to_glist_args args;
+
+    args.ary = rb_ary_to_ary(value);
+    args.n = RARRAY_LEN(args.ary);
+    args.result = NULL;
+
+    rb_rescue(rbgio_gfile_ary_to_glist_body, (VALUE)&args,
+              rbgio_gfile_ary_to_glist_rescue, (VALUE)&args);
+
+    return args.result;
 }
 
 GList *
@@ -165,39 +195,6 @@ rbgio_rval_to_gtimeval(VALUE value, GTimeVal *time)
         }
 }
 
-VALUE
-rbgio_str_vector_to_ary(const gchar * const *vector)
-{
-        int i, n;
-        VALUE ary;
-
-        if (vector == NULL)
-             return Qnil;
- 
-        for (i = n = 0; vector[i] != NULL; i++)
-                n++;
-        ary = rb_ary_new2(n);
-        for (i = 0; i < n; i++)
-                RARRAY_PTR(ary)[i] = CSTR2RVAL(vector[i]);
-
-        return ary;
-}
-
-static VALUE
-rbgio_str_vector_to_ary_free_ensure(gchar **vector)
-{
-        g_strfreev(vector);
-
-        return Qnil;
-}
-
-VALUE
-rbgio_str_vector_to_ary_free(gchar **vector)
-{
-        return rb_ensure(rbgio_str_vector_to_ary, (VALUE)vector,
-                         rbgio_str_vector_to_ary_free_ensure, (VALUE)vector);
-}
-
 struct async_ready_callback_data
 {
         GAsyncResult *result;
