@@ -2,7 +2,7 @@
 
 class TestFileEnumerator < Test::Unit::TestCase
   def test_responds_to_properties
-    a = GLib::File.new_for_path('/').enumerate_children
+    a = Gio::File.new_for_path('/').enumerate_children
     assert a.respond_to?(:container)
   end
 end
