@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2011-2013  Ruby-GNOME2 Project Team
  *  Copyright (C) 2002,2003  Masahiro Sakai
  *
  *  This library is free software; you can redistribute it and/or
@@ -825,6 +825,37 @@ rbg_inspect (VALUE object)
     return StringValueCStr(inspected);
 }
 
+VALUE
+rbg_to_array (VALUE object)
+{
+    return rb_convert_type(object, RUBY_T_ARRAY, "Array", "to_ary");
+}
+
+VALUE
+rbg_to_hash (VALUE object)
+{
+    return rb_convert_type(object, RUBY_T_HASH, "Hash", "to_hash");
+}
+
+VALUE
+rbg_check_array_type (VALUE object)
+{
+#ifdef HAVE_RB_CHECK_ARRAY_TYPE
+    return rb_check_array_type(object);
+#else
+    return rb_check_convert_type(object, RUBY_T_ARRAY, "Array", "to_ary");
+#endif
+}
+
+VALUE
+rbg_check_hash_type (VALUE object)
+{
+#ifdef HAVE_RB_CHECK_HASH_TYPE
+    return rb_check_hash_type(object);
+#else
+    return rb_check_convert_type(object, RUBY_T_HASH, "Hash", "to_hash");
+#endif
+}
 
 void
 rbg_scan_options (VALUE options, ...)
@@ -835,7 +866,7 @@ rbg_scan_options (VALUE options, ...)
     VALUE *value;
     va_list args;
 
-    options = rb_check_convert_type(options, T_HASH, "Hash", "to_hash");
+    options = rbg_check_hash_type(options);
     if (NIL_P(options)) {
         options = rb_hash_new();
     } else if (options == original_options) {
@@ -998,7 +1029,6 @@ Init_glib2(void)
     rb_define_const(RG_TARGET_NAMESPACE, "MAXLONG", INT2NUM(G_MAXLONG));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXULONG", UINT2NUM(G_MAXULONG));
 
-#if GLIB_CHECK_VERSION(2,4,0)
     rb_define_const(RG_TARGET_NAMESPACE, "MININT8", INT2FIX(G_MININT8));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXINT8", INT2FIX(G_MAXINT8));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXUINT8", UINT2NUM(G_MAXUINT8));
@@ -1010,13 +1040,13 @@ Init_glib2(void)
     rb_define_const(RG_TARGET_NAMESPACE, "MININT32", INT2FIX(G_MININT32));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXINT32", INT2NUM(G_MAXINT32));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXUINT32", UINT2NUM(G_MAXUINT32));
-#endif
+
     rb_define_const(RG_TARGET_NAMESPACE, "MININT64", INT2FIX(G_MININT64));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXINT64", LL2NUM(G_MAXINT64));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXUINT64", ULL2NUM(G_MAXUINT64));
-#if GLIB_CHECK_VERSION(2,4,0)
+
     rb_define_const(RG_TARGET_NAMESPACE, "MAXSIZE", UINT2NUM(G_MAXSIZE));
-#endif
+
     rb_define_const(RG_TARGET_NAMESPACE, "MINFLOAT", INT2FIX(G_MINFLOAT));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXFLOAT", DBL2NUM(G_MAXFLOAT));
 
@@ -1090,6 +1120,8 @@ union       GDoubleIEEE754;
 /*    Init_mem(); */
     Init_gutil();
     Init_gutil_callback();
+
+    Init_glib_gettext();
     Init_glib_int64();
     Init_glib_error();
     Init_glib_threads();
@@ -1109,12 +1141,12 @@ union       GDoubleIEEE754;
     Init_glib_source();
     Init_glib_main_context();
     Init_glib_poll_fd();
+    Init_glib_io_constants();
     Init_glib_io_channel();
     Init_glib_io_channelerror();
     Init_glib_io_channel_win32_socket();
     Init_glib_shell();
     Init_glib_shellerror();
-    Init_glib_completion();
     Init_glib_timer();
     Init_glib_unicode();
     Init_glib_utf8();
