@@ -1,13 +1,23 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbglib_maincontext.c -
-
-  $Author: ktou $
-  $Date: 2007/08/30 10:13:44 $
-
-  Copyright (C) 2005 Masao Mutoh
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2005  Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "rbgprivate.h"
 
@@ -21,12 +31,13 @@
 #  endif
 #endif
 
+GStaticPrivate rg_polling_key = G_STATIC_PRIVATE_INIT;
+
 /*
 static ID id_poll_func;
 */
 static ID id_call;
 
-
 static VALUE mGLibSource;
 static ID id__callbacks__;
 static GHashTable *callbacks_table;
@@ -75,13 +86,15 @@ rg_poll(GPollFD *ufds, guint nfsd, gint timeout)
     info.timeout = timeout;
     info.result = 0;
 
+    g_static_private_set(&rg_polling_key, GINT_TO_POINTER(TRUE), NULL);
     rb_thread_blocking_region(rg_poll_in_blocking, &info, RUBY_UBF_IO, NULL);
+    g_static_private_set(&rg_polling_key, GINT_TO_POINTER(FALSE), NULL);
 
     return info.result;
 }
 
 static VALUE
-ruby_source_set_priority (VALUE self, VALUE priority)
+ruby_source_set_priority (G_GNUC_UNUSED VALUE self, G_GNUC_UNUSED VALUE priority)
 {
     return Qnil;
 }
@@ -101,7 +114,7 @@ rg_poll(GPollFD *ufds, guint nfsd, gint timeout)
 #endif
 
 static void
-restore_poll_func(VALUE data)
+restore_poll_func(G_GNUC_UNUSED VALUE data)
 {
     if (g_main_context_get_poll_func(NULL) == (GPollFunc)rg_poll) {
         g_main_context_set_poll_func(NULL, default_poll_func);
@@ -112,11 +125,11 @@ restore_poll_func(VALUE data)
 static guint ruby_source_id = 0;
 
 /* from eval.c */
-#define WAIT_FD		(1<<0)
-#define WAIT_SELECT	(1<<1)
-#define WAIT_TIME	(1<<2)
-#define WAIT_JOIN	(1<<3)
-#define WAIT_PID	(1<<4)
+#define WAIT_FD     (1<<0)
+#define WAIT_SELECT (1<<1)
+#define WAIT_TIME   (1<<2)
+#define WAIT_JOIN   (1<<3)
+#define WAIT_PID    (1<<4)
 
 #define DELAY_INFTY 1E30
 
@@ -130,7 +143,7 @@ static guint ruby_source_id = 0;
 #endif
 
 static double
-timeofday()
+timeofday(void)
 {
     struct timeval tv;
 #if CHECK_RUBY_RELEASE_DATE(2009, 1, 7)
@@ -153,7 +166,7 @@ timeofday()
     struct timespec tp;
 
     if (clock_gettime(CLOCK_MONOTONIC, &tp) == 0) {
-	return (double)tp.tv_sec + (double)tp.tv_nsec * 1e-9;
+        return (double)tp.tv_sec + (double)tp.tv_nsec * 1e-9;
     }
 #  endif
 #endif
@@ -322,7 +335,9 @@ source_check(GSource *source)
 }
 
 static gboolean
-source_dispatch(GSource *source, GSourceFunc callback, gpointer user_data)
+source_dispatch(G_GNUC_UNUSED GSource *source,
+                G_GNUC_UNUSED GSourceFunc callback,
+                G_GNUC_UNUSED gpointer user_data)
 {
     TRAP_BEG;
     rb_thread_schedule();
@@ -358,7 +373,9 @@ static GSourceFuncs source_funcs = {
     source_prepare,
     source_check,
     source_dispatch,
-    source_finalize
+    source_finalize,
+    NULL,
+    NULL
 };
 
 static GSource *
@@ -378,7 +395,7 @@ ruby_source_new(void)
 }
 
 static VALUE
-ruby_source_set_priority (VALUE self, VALUE priority)
+ruby_source_set_priority(G_GNUC_UNUSED VALUE self, VALUE priority)
 {
     GSource *ruby_source = NULL;
 
@@ -393,7 +410,7 @@ ruby_source_set_priority (VALUE self, VALUE priority)
 #endif
 
 static VALUE
-source_remove(VALUE self, VALUE tag)
+source_remove(G_GNUC_UNUSED VALUE self, VALUE tag)
 {
     VALUE callback;
     callback = G_GET_RELATIVE(mGLibSource, id__callbacks__, tag);
@@ -402,13 +419,11 @@ source_remove(VALUE self, VALUE tag)
     return CBOOL2RVAL(g_source_remove(NUM2UINT(tag)));
 }
 
-#if GLIB_CHECK_VERSION(2,12,0)
 static VALUE
-source_current_source(VALUE self)
+source_current_source(G_GNUC_UNUSED VALUE self)
 {
     return BOXED2RVAL(g_main_current_source, G_TYPE_SOURCE);
 }
-#endif
 
 static gboolean
 invoke_source_func(gpointer data)
@@ -422,8 +437,8 @@ invoke_source_func(gpointer data)
     return ret;
 }
 
-
 /*****************************************/
+#if !GLIB_CHECK_VERSION(2,30,0)
 GType
 g_main_context_get_type(void)
 {
@@ -434,12 +449,14 @@ g_main_context_get_type(void)
                     (GBoxedFreeFunc)g_main_context_unref);
   return our_type;
 }
+#endif
 /*****************************************/
 
+#define RG_TARGET_NAMESPACE cMainContext
 #define _SELF(s) ((GMainContext*)RVAL2BOXED(s, G_TYPE_MAIN_CONTEXT))
 
 static VALUE
-mc_initialize(VALUE self)
+rg_initialize(VALUE self)
 {
     GMainContext *context;
 
@@ -460,25 +477,25 @@ mc_initialize(VALUE self)
 }
 
 static VALUE
-mc_s_default(VALUE self)
+rg_s_default(G_GNUC_UNUSED VALUE self)
 {
     return BOXED2RVAL(g_main_context_default(), G_TYPE_MAIN_CONTEXT);
 }
 
 static VALUE
-mc_iteration(VALUE self, VALUE may_block)
+rg_iteration(VALUE self, VALUE may_block)
 {
     return CBOOL2RVAL(g_main_context_iteration(_SELF(self), RVAL2CBOOL(may_block)));
 }
 
 static VALUE
-mc_pending(VALUE self)
+rg_pending_p(VALUE self)
 {
     return CBOOL2RVAL(g_main_context_pending(_SELF(self)));
 }
 
 static VALUE
-mc_find_source(VALUE self, VALUE source_id)
+rg_find_source(VALUE self, VALUE source_id)
 {
     GSource* src = g_main_context_find_source_by_id(_SELF(self), NUM2UINT(source_id));
     return BOXED2RVAL(src, G_TYPE_SOURCE);
@@ -495,32 +512,30 @@ GSource*    g_main_context_find_source_by_funcs_user_data
 */
 
 static VALUE
-mc_wakeup(VALUE self)
+rg_wakeup(VALUE self)
 {
     g_main_context_wakeup(_SELF(self));
     return self;
 }
 
 static VALUE
-mc_acquire(VALUE self)
+rg_acquire(VALUE self)
 {
     return CBOOL2RVAL(g_main_context_acquire(_SELF(self)));
 }
 
 static VALUE
-mc_release(VALUE self)
+rg_release(VALUE self)
 {
     g_main_context_release(_SELF(self));
     return self;
 }
 
-#if GLIB_CHECK_VERSION(2,10,0)
 static VALUE
-mc_is_owner(VALUE self)
+rg_owner_p(VALUE self)
 {
     return CBOOL2RVAL(g_main_context_is_owner(_SELF(self)));
 }
-#endif
 
 /*
 gboolean    g_main_context_wait             (GMainContext *context,
@@ -529,7 +544,7 @@ gboolean    g_main_context_wait             (GMainContext *context,
 */
 
 static VALUE
-mc_prepare(VALUE self)
+rg_prepare(VALUE self)
 {
     gint priority;
     gboolean ret = g_main_context_prepare(_SELF(self), &priority);
@@ -538,9 +553,9 @@ mc_prepare(VALUE self)
 }
 
 struct mc_query_body_args {
-    GPollFD *fds;
     gint timeout_;
-    gint ret;
+    GPollFD *fds;
+    gint n_fds;
 };
 
 static VALUE
@@ -550,9 +565,9 @@ mc_query_body(VALUE value)
     gint i;
     VALUE ary = rb_ary_new();
 
-    for (i = 0; i < args->ret; i++)
+    for (i = 0; i < args->n_fds; i++)
         rb_ary_push(ary, BOXED2RVAL(&args->fds[i], G_TYPE_POLL_FD));
-    
+
     return rb_assoc_new(INT2NUM(args->timeout_), ary);
 }
 
@@ -564,38 +579,36 @@ mc_query_ensure(VALUE value)
     return Qnil;
 }
 
+#define QUERY_DEFAULT_FDS 100
+
 static VALUE
-mc_query(VALUE self, VALUE max_priority)
+rg_query(VALUE self, VALUE rbmax_priority)
 {
+    GMainContext *context = _SELF(self);
+    gint max_priority = NUM2INT(rbmax_priority);
     gint timeout_;
+    GPollFD *fds;
+    gint n_fds;
     struct mc_query_body_args args;
-   
-    GPollFD *fds = g_new(GPollFD, 100);
-    gint ret = g_main_context_query(_SELF(self),
-                                    NUM2INT(max_priority), 
-                                    &timeout_,
-                                    fds,
-                                    100);
-    if (ret > 100) {
+
+    fds = g_new(GPollFD, QUERY_DEFAULT_FDS);
+    n_fds = g_main_context_query(context, max_priority, &timeout_, fds, QUERY_DEFAULT_FDS);
+    if (n_fds > QUERY_DEFAULT_FDS) {
         g_free(fds);
-        fds = g_new(GPollFD, ret);
-        g_main_context_query(_SELF(self),
-                             NUM2INT(max_priority),
-                             &timeout_,
-                             fds,
-                             ret);
+        fds = g_new(GPollFD, n_fds);
+        g_main_context_query(context, max_priority, &timeout_, fds, n_fds);
     }
 
-    args.fds = fds;
     args.timeout_ = timeout_;
-    args.ret = ret;
+    args.fds = fds;
+    args.n_fds = n_fds;
     return rb_ensure(mc_query_body, (VALUE)&args,
                      mc_query_ensure, (VALUE)fds);
 }
 
 /* How can I implement this?
 static VALUE
-mc_check(VALUE self, VALUE max_priority)
+rg_check(VALUE self, VALUE max_priority)
 {
     gint i, timeout_;
     VALUE ary;
@@ -610,7 +623,7 @@ mc_check(VALUE self, VALUE max_priority)
 
     g_free(fds);
     fds = g_new (GPollFD, n_fds);    
-    
+
     ret = g_main_context_check(_SELF(self), NUM2INT(max_priority),
                                fds, n_fds);
     printf("ret = %d\n", ret);
@@ -624,7 +637,7 @@ mc_check(VALUE self, VALUE max_priority)
 */
 
 static VALUE
-mc_dispatch(VALUE self)
+rg_dispatch(VALUE self)
 {
     g_main_context_dispatch(_SELF(self));
     return self;
@@ -635,14 +648,14 @@ static gint
 poll_func(GPollFD *ufds, guint nfsd, gint timeout_)
 {
     VALUE func = rb_ivar_get(self, id_poll_func);
-    if NIL_P(func) return -1;
+    if (NIL_P(func)) return -1;
 
     return INT2NUM(rb_funcall(func, 3, BOXED2RVAL(ufds, G_TYPE_POLL_FD),
                               UINT2NUM(nfsd), INT2NUM(timeout_)));
 }
 
 static VALUE
-mc_set_poll_func(VALUE self)
+rg_set_poll_func(VALUE self)
 {
     rb_ivar_set(self, id_poll_func, rb_block_proc());
     g_main_context_set_poll_func(_SELF(self), (GPollFunc)poll_func);
@@ -656,7 +669,7 @@ GPollFunc   g_main_context_get_poll_func    (GMainContext *context);
 */
 
 static VALUE
-mc_add_poll(VALUE self, VALUE fd, VALUE priority)
+rg_add_poll(VALUE self, VALUE fd, VALUE priority)
 {
     g_main_context_add_poll(_SELF(self), RVAL2BOXED(fd, G_TYPE_POLL_FD),
                             NUM2INT(priority));
@@ -664,7 +677,7 @@ mc_add_poll(VALUE self, VALUE fd, VALUE priority)
 }
 
 static VALUE
-mc_remove_poll(VALUE self, VALUE fd)
+rg_remove_poll(VALUE self, VALUE fd)
 {
     g_main_context_remove_poll(_SELF(self), RVAL2BOXED(fd, G_TYPE_POLL_FD));
     return self;
@@ -672,28 +685,27 @@ mc_remove_poll(VALUE self, VALUE fd)
 
 #ifdef HAVE_G_MAIN_DEPTH
 static VALUE
-mc_s_depth(VALUE self)
+rg_s_depth(G_GNUC_UNUSED VALUE self)
 {
     return INT2NUM(g_main_depth());
 }
 #endif
 
-
 static VALUE
-timeout_source_new(VALUE self, VALUE interval)
+timeout_source_new(G_GNUC_UNUSED VALUE self, VALUE interval)
 {
     return BOXED2RVAL(g_timeout_source_new(NUM2UINT(interval)), G_TYPE_SOURCE);
 }
 #if GLIB_CHECK_VERSION(2,14,0)
 static VALUE
-timeout_source_new_seconds(VALUE self, VALUE interval)
+timeout_source_new_seconds(G_GNUC_UNUSED VALUE self, VALUE interval)
 {
     return BOXED2RVAL(g_timeout_source_new_seconds(NUM2UINT(interval)), G_TYPE_SOURCE);
 }
 #endif
 
 static VALUE
-timeout_add(int argc, VALUE *argv, VALUE self)
+timeout_add(int argc, VALUE *argv, G_GNUC_UNUSED VALUE self)
 {
     VALUE interval, rb_priority, func, rb_id;
     gint priority;
@@ -717,7 +729,7 @@ timeout_add(int argc, VALUE *argv, VALUE self)
 
 #if GLIB_CHECK_VERSION(2,14,0)
 static VALUE
-timeout_add_seconds(int argc, VALUE *argv, VALUE self)
+timeout_add_seconds(int argc, VALUE *argv, G_GNUC_UNUSED VALUE self)
 {
     VALUE interval, rb_priority, func, rb_id;
     gint priority;
@@ -743,13 +755,13 @@ timeout_add_seconds(int argc, VALUE *argv, VALUE self)
 #endif
 
 static VALUE
-idle_source_new(VALUE self)
+idle_source_new(G_GNUC_UNUSED VALUE self)
 {
     return BOXED2RVAL(g_idle_source_new(), G_TYPE_SOURCE);
 }
 
 static VALUE
-idle_add(gint argc, VALUE *argv, VALUE self)
+idle_add(gint argc, VALUE *argv, G_GNUC_UNUSED VALUE self)
 {
     VALUE arg1, arg2, func, rb_id;
     callback_info_t *info;
@@ -779,7 +791,7 @@ idle_add(gint argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-idle_remove(VALUE self, VALUE func)
+idle_remove(G_GNUC_UNUSED VALUE self, VALUE func)
 {
     callback_info_t *info;
 
@@ -789,9 +801,8 @@ idle_remove(VALUE self, VALUE func)
     return CBOOL2RVAL(g_idle_remove_by_data((gpointer)info));
 }
 
-#if GLIB_CHECK_VERSION(2,4,0)
 static VALUE
-child_watch_source_new(VALUE self, VALUE pid)
+child_watch_source_new(G_GNUC_UNUSED VALUE self, VALUE pid)
 {
     return BOXED2RVAL(g_child_watch_source_new((GPid)NUM2INT(pid)), G_TYPE_SOURCE);
 }
@@ -810,11 +821,10 @@ child_watch_add(VALUE self, VALUE pid)
     return UINT2NUM(g_child_watch_add((GPid)NUM2INT(pid), 
                                       (GChildWatchFunc)child_watch_func, (gpointer)func));
 }
-#endif
 
 #ifndef HAVE_RB_THREAD_BLOCKING_REGION
 static void
-ruby_source_remove(VALUE data)
+ruby_source_remove(G_GNUC_UNUSED VALUE data)
 {
     if (ruby_source_id != 0) {
         g_source_remove(ruby_source_id);
@@ -824,75 +834,64 @@ ruby_source_remove(VALUE data)
 #endif
 
 void
-Init_glib_main_context()
+Init_glib_main_context(void)
 {
-    VALUE mc = G_DEF_CLASS(G_TYPE_MAIN_CONTEXT, "MainContext", mGLib); 
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(G_TYPE_MAIN_CONTEXT, "MainContext", mGLib); 
 
     VALUE timeout = rb_define_module_under(mGLib, "Timeout");
     VALUE idle = rb_define_module_under(mGLib, "Idle");
-#if GLIB_CHECK_VERSION(2,4,0)
     VALUE child_watch = rb_define_module_under(mGLib, "ChildWatch");
-#endif
 
     id_call = rb_intern("call");
     id__callbacks__ = rb_intern("__callbacks__");
     callbacks_table = g_hash_table_new(NULL, NULL);
 
-    rb_define_singleton_method(mGLib, "set_ruby_thread_priority",
-                               ruby_source_set_priority, 1);
-    rb_define_singleton_method(mGLib, "ruby_thread_priority=",
+    rbg_define_singleton_method(mGLib, "set_ruby_thread_priority",
                                ruby_source_set_priority, 1);
 
     mGLibSource = rb_const_get(mGLib, rb_intern("Source"));
-    rb_define_singleton_method(mGLibSource, "remove", source_remove, 1);
-#if GLIB_CHECK_VERSION(2,12,0)
-    rb_define_singleton_method(mGLibSource, "current", source_current_source, 0);
-#endif
+    rbg_define_singleton_method(mGLibSource, "remove", source_remove, 1);
+    rbg_define_singleton_method(mGLibSource, "current", source_current_source, 0);
 /*
     id_poll_func = rb_intern("__poll_func__");
 */
-    rb_define_method(mc, "initialize", mc_initialize, 0);
-    rb_define_singleton_method(mc, "default", mc_s_default, 0);
-    rb_define_method(mc, "iteration", mc_iteration, 1);
-    rb_define_method(mc, "pending?", mc_pending, 0);
-    rb_define_method(mc, "find_source", mc_find_source, 1);
-    rb_define_method(mc, "wakeup", mc_wakeup, 0);
-    rb_define_method(mc, "acquire", mc_acquire, 0);
-    rb_define_method(mc, "release", mc_release, 0);
-#if GLIB_CHECK_VERSION(2,10,0)
-    rb_define_method(mc, "owner?", mc_is_owner, 0);
-#endif
-    rb_define_method(mc, "prepare", mc_prepare, 0);
-    rb_define_method(mc, "query", mc_query, 1);
+    RG_DEF_METHOD(initialize, 0);
+    RG_DEF_SMETHOD(default, 0);
+    RG_DEF_METHOD(iteration, 1);
+    RG_DEF_METHOD_P(pending, 0);
+    RG_DEF_METHOD(find_source, 1);
+    RG_DEF_METHOD(wakeup, 0);
+    RG_DEF_METHOD(acquire, 0);
+    RG_DEF_METHOD(release, 0);
+    RG_DEF_METHOD_P(owner, 0);
+    RG_DEF_METHOD(prepare, 0);
+    RG_DEF_METHOD(query, 1);
 /*
-    rb_define_method(mc, "check", mc_check, 1);
+    RG_DEF_METHOD(check, 1);
 */
-    rb_define_method(mc, "dispatch", mc_dispatch, 0);
+    RG_DEF_METHOD(dispatch, 0);
 /*
-    rb_define_method(mc, "set_poll_func", mc_set_poll_func, 0);
+    RG_DEF_METHOD(set_poll_func, 0);
 */
-    rb_define_method(mc, "add_poll", mc_add_poll, 2);
-    rb_define_method(mc, "remove_poll", mc_remove_poll, 1);
+    RG_DEF_METHOD(add_poll, 2);
+    RG_DEF_METHOD(remove_poll, 1);
 #ifdef HAVE_G_MAIN_DEPTH
-    rb_define_singleton_method(mc, "depth", mc_s_depth, 0);
+    RG_DEF_SMETHOD(depth, 0);
 #endif
-    rb_define_module_function(timeout, "source_new", timeout_source_new, 1);
+    rbg_define_singleton_method(timeout, "source_new", timeout_source_new, 1);
 #if GLIB_CHECK_VERSION(2,14,0)
-    rb_define_module_function(timeout, "source_new_seconds", timeout_source_new_seconds, 1);
+    rbg_define_singleton_method(timeout, "source_new_seconds", timeout_source_new_seconds, 1);
 #endif
-    rb_define_module_function(timeout, "add", timeout_add, -1);
+    rbg_define_singleton_method(timeout, "add", timeout_add, -1);
 #if GLIB_CHECK_VERSION(2,14,0)
-    rb_define_module_function(timeout, "add_seconds", timeout_add_seconds, -1);
-#endif
-    rb_define_module_function(idle, "source_new", idle_source_new, 0);
-    rb_define_module_function(idle, "add", idle_add, -1);
-    rb_define_module_function(idle, "remove", idle_remove, 1);
-
-#if GLIB_CHECK_VERSION(2,4,0)
-    rb_define_module_function(child_watch, "source_new", child_watch_source_new, 1);
-    rb_define_module_function(child_watch, "add", child_watch_add, 1);
+    rbg_define_singleton_method(timeout, "add_seconds", timeout_add_seconds, -1);
 #endif
+    rbg_define_singleton_method(idle, "source_new", idle_source_new, 0);
+    rbg_define_singleton_method(idle, "add", idle_add, -1);
+    rbg_define_singleton_method(idle, "remove", idle_remove, 1);
 
+    rbg_define_singleton_method(child_watch, "source_new", child_watch_source_new, 1);
+    rbg_define_singleton_method(child_watch, "add", child_watch_add, 1);
 
     default_poll_func = g_main_context_get_poll_func(NULL);
     g_main_context_set_poll_func(NULL, rg_poll);
