@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2011-2013  Ruby-GNOME2 Project Team
  *  Copyright (C) 2005  Masao Mutoh
  *
  *  This library is free software; you can redistribute it and/or
@@ -54,19 +54,20 @@ GSource*    g_source_new                    (GSourceFuncs *source_funcs,
 */
 
 static VALUE
-rg_attach(VALUE self, VALUE context)
+rg_attach(int argc, VALUE *argv, VALUE self)
 {
-    return UINT2NUM(g_source_attach(_SELF(self), 
+    VALUE context;
+
+    rb_scan_args(argc, argv, "01", &context);
+    return UINT2NUM(g_source_attach(_SELF(self),
                                     RVAL2BOXED(context, G_TYPE_MAIN_CONTEXT)));
 }
 
-#if GLIB_CHECK_VERSION(2,12,0)
 static VALUE
 rg_destroyed_p(VALUE self)
 {
     return CBOOL2RVAL(g_source_is_destroyed(_SELF(self)));
 }
-#endif
 
 static VALUE
 rg_set_priority(VALUE self, VALUE priority)
@@ -145,14 +146,15 @@ rg_remove_poll(VALUE self, VALUE fd)
     return self;
 }
 
+#if GLIB_CHECK_VERSION(2, 28, 0)
 static VALUE
-rg_current_time(VALUE self)
+rg_time(VALUE self)
 {
-    GTimeVal timeval;
-    g_source_get_current_time(_SELF(self), &timeval);
-
-    return rb_assoc_new(LONG2NUM(timeval.tv_sec), LONG2NUM(timeval.tv_usec));
+    gint64 time;
+    time = g_source_get_time(_SELF(self));
+    return LL2NUM(time);
 }
+#endif
 
 /* How can I implement them ?
 gboolean    g_source_remove_by_funcs_user_data
@@ -168,10 +170,13 @@ Init_glib_source(void)
 
     id_call = rb_intern("call");
 
-    RG_DEF_METHOD(attach, 1);
-#if GLIB_CHECK_VERSION(2,12,0)
+    rb_define_const(RG_TARGET_NAMESPACE,
+                    "REMOVE", CBOOL2RVAL(G_SOURCE_REMOVE));
+    rb_define_const(RG_TARGET_NAMESPACE,
+                    "CONTINUE", CBOOL2RVAL(G_SOURCE_CONTINUE));
+
+    RG_DEF_METHOD(attach, -1);
     RG_DEF_METHOD_P(destroyed, 0);
-#endif
     RG_DEF_METHOD(set_priority, 1);
     RG_DEF_METHOD(priority, 0);
     RG_DEF_METHOD(set_can_recurse, 1);
@@ -181,7 +186,9 @@ Init_glib_source(void)
     RG_DEF_METHOD(set_callback, 0);
     RG_DEF_METHOD(add_poll, 1);
     RG_DEF_METHOD(remove_poll, 1);
-    RG_DEF_METHOD(current_time, 0);
+#if GLIB_CHECK_VERSION(2, 28, 0)
+    RG_DEF_METHOD(time, 0);
+#endif
 
     /* GLib::Source.remove is moved to rbglib_maincontext.c */
 }
