@@ -156,22 +156,10 @@ rbgobj_get_gobject(VALUE obj)
     return holder->gobj;
 }
 
-static VALUE
-dummy_init(int argc, VALUE *argv, VALUE self)
-{
-    GType gtype = CLASS2GTYPE(CLASS_OF(self));
-    if (G_TYPE_IS_ABSTRACT(gtype))
-        rb_raise(rb_eTypeError, "initializing abstract class");
-    else
-        return rb_call_super(argc, argv);
-}
-
 void
 rbgobj_init_object_class(VALUE klass)
 {
     rbgobj_define_property_accessors(klass);
-    if (G_TYPE_IS_ABSTRACT(CLASS2GTYPE(klass)))
-        rbg_define_method(klass, "initialize", dummy_init, -1);
 }
 
 /**********************************************************************/
@@ -225,7 +213,7 @@ rg_s_new_bang(int argc, VALUE *argv, VALUE self)
     rb_scan_args(argc, argv, "01", &params_hash);
 
     if (!NIL_P(params_hash))
-        Check_Type(params_hash, T_HASH);
+        Check_Type(params_hash, RUBY_T_HASH);
 
     if (cinfo->klass != self)
         rb_raise(rb_eTypeError, "%s isn't registered class",
@@ -629,13 +617,21 @@ rg_type_name(VALUE self)
 static VALUE
 rg_initialize(int argc, VALUE *argv, VALUE self)
 {
+    GType gtype;
     VALUE params_hash;
     GObject* gobj;
 
+    gtype = CLASS2GTYPE(CLASS_OF(self));
+    if (G_TYPE_IS_ABSTRACT(gtype)) {
+        rb_raise(rb_eTypeError,
+                 "initializing abstract class: %s",
+                 RBG_INSPECT(CLASS_OF(self)));
+    }
+
     rb_scan_args(argc, argv, "01", &params_hash);
 
     if (!NIL_P(params_hash))
-        Check_Type(params_hash, T_HASH);
+        Check_Type(params_hash, RUBY_T_HASH);
 
     gobj = rbgobj_gobject_new(RVAL2GTYPE(self), params_hash);
 
