@@ -1,7 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2011  Ruby-GNOME2 Project Team
- *  Copyright (C) 2002-2009  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2013  Ruby-GNOME2 Project Team
  *  Copyright (C) 2002,2003  Masahiro Sakai
  *
  *  This library is free software; you can redistribute it and/or
@@ -27,10 +26,6 @@
 /**********************************************************************/
 /* Type Mapping */
 
-#ifdef RBGOBJ_USE_DLPTR
-#include "dl.h"
-#endif
-
 static VALUE rb_cMutex;
 static VALUE lookup_class_mutex;
 
@@ -45,8 +40,8 @@ static GHashTable* dynamic_gtype_list;
 typedef struct {
     const gchar* name;
     VALUE module;
-    void (*mark)(gpointer);
-    void (*free)(gpointer);
+    RGMarkFunc mark;
+    RGFreeFunc free;
     int flags; /* RGObjClassFlag */
 } RGObjClassInfoDynamic;
 
@@ -104,24 +99,25 @@ get_superclass(GType gtype)
       case G_TYPE_BOXED:
         return rb_cObject;
       case G_TYPE_POINTER:
-#ifdef RBGOBJ_USE_DLPTR
-        return rb_cDLPtrData;
-#else
         return rb_cData;
-#endif
       case G_TYPE_ENUM:
       case G_TYPE_FLAGS:
         return rb_cObject;
       default:
       {
-          const RGObjClassInfo *cinfo_super;
           GType parent_type;
 
           parent_type = g_type_parent(gtype);
-          cinfo_super = rbgobj_lookup_class_by_gtype_without_lock(parent_type,
-                                                                  Qnil,
-                                                                  TRUE);
-          return cinfo_super->klass;
+          if (parent_type == G_TYPE_INVALID) {
+              return cInstantiatable;
+          } else {
+              const RGObjClassInfo *cinfo_super;
+              cinfo_super =
+                  rbgobj_lookup_class_by_gtype_without_lock(parent_type,
+                                                            Qnil,
+                                                            TRUE);
+              return cinfo_super->klass;
+          }
       }
     }
 }
@@ -298,7 +294,8 @@ rbgobj_gtype_to_ruby_class(GType gtype)
 }
 
 VALUE
-rbgobj_define_class(GType gtype, const gchar *name, VALUE module, void *mark, void *free, VALUE parent)
+rbgobj_define_class(GType gtype, const gchar *name, VALUE module,
+                    RGMarkFunc mark, RGFreeFunc free, VALUE parent)
 {
     RGObjClassInfo* cinfo;
     if (gtype == 0)
@@ -311,8 +308,39 @@ rbgobj_define_class(GType gtype, const gchar *name, VALUE module, void *mark, vo
     return cinfo->klass;
 }
 
+void
+rbgobj_register_mark_func(GType gtype, RGMarkFunc mark)
+{
+    RGObjClassInfo *cinfo;
+
+    cinfo =
+        (RGObjClassInfo *)rbgobj_lookup_class_by_gtype_full(gtype, Qnil, FALSE);
+    if (!cinfo) {
+        rb_raise(rb_eArgError,
+                 "rbgobj_register_free_func(): no class is defined: <%s>",
+                 g_type_name(gtype));
+    }
+    cinfo->mark = mark;
+}
+
+void
+rbgobj_register_free_func(GType gtype, RGFreeFunc free)
+{
+    RGObjClassInfo *cinfo;
+
+    cinfo =
+        (RGObjClassInfo *)rbgobj_lookup_class_by_gtype_full(gtype, Qnil, FALSE);
+    if (!cinfo) {
+        rb_raise(rb_eArgError,
+                 "rbgobj_register_free_func(): no class is defined: <%s>",
+                 g_type_name(gtype));
+    }
+    cinfo->free = free;
+}
+
 VALUE
-rbgobj_define_class_dynamic(const gchar *gtype_name, const gchar *name, VALUE module, void *mark, void *free)
+rbgobj_define_class_dynamic(const gchar *gtype_name, const gchar *name,
+                            VALUE module, RGMarkFunc mark, RGFreeFunc free)
 {
     RGObjClassInfoDynamic* cinfo;
     cinfo = (RGObjClassInfoDynamic*)g_new(RGObjClassInfoDynamic, 1);
@@ -429,8 +457,7 @@ rg_initialize(VALUE self, VALUE type)
     GType gtype;
 
     if (RVAL2CBOOL(rb_obj_is_kind_of(type, rb_cInteger))) {
-        gtype = NUM2UINT(type);
-        // XXX
+        gtype = NUM2ULONG(type);
         if (!g_type_name(gtype))
             gtype = G_TYPE_INVALID;
     } else {
@@ -440,7 +467,7 @@ rg_initialize(VALUE self, VALUE type)
     if (G_TYPE_INVALID == gtype)
         rb_raise(rb_eArgError, "invalid type");
 
-    rb_ivar_set(self, id_gtype, UINT2NUM(gtype));
+    rb_ivar_set(self, id_gtype, ULONG2NUM(gtype));
 
     return Qnil;
 }
@@ -729,7 +756,10 @@ _def_fundamental_type(VALUE ary, GType gtype, const char* name)
 void
 Init_gobject_gtype(void)
 {
+#if !GLIB_CHECK_VERSION(2, 35, 1)
     g_type_init();
+#endif
+
     init_typemap();
 
     /* type */
