@@ -45,8 +45,10 @@ extern "C" {
     G_DEF_CLASS_WITH_GC_FUNC(gtype, name, module, mark, free)
 #define G_DEF_CLASS3(gtype_name, name, module)\
     (rbgobj_define_class_dynamic(gtype_name, name, module, 0, 0))
-#define G_DEF_CLASS4(gtype, name, module, parent) \
+#define G_DEF_CLASS_WITH_PARENT(gtype, name, module, parent) \
     (rbgobj_define_class(gtype, name, module, 0, 0, parent))
+#define G_DEF_CLASS4(gtype, name, module, parent) \
+    G_DEF_CLASS_WITH_PARENT(gtype, name, module, parent)
 
 #define G_DEF_INTERFACE(gtype, name, module)\
     (rbgobj_define_class(gtype, name, module, 0, 0, Qnil))
@@ -122,12 +124,15 @@ typedef enum
     RBGOBJ_BOXED_NOT_COPY         = 1 << 1,
     RBGOBJ_DEFINED_BY_RUBY        = 1 << 2,
 } RGObjClassFlag;
-    
+
+typedef void (*RGMarkFunc)(gpointer object);
+typedef void (*RGFreeFunc)(gpointer object);
+
 typedef struct {
     VALUE klass;
     GType gtype;
-    void (*mark)(gpointer);
-    void (*free)(gpointer);
+    RGMarkFunc mark;
+    RGFreeFunc free;
     int flags; /* RGObjClassFlag */
 } RGObjClassInfo;
 
@@ -138,6 +143,7 @@ extern gpointer rbgobj_instance_from_ruby_object(VALUE obj);
 extern VALUE rbgobj_ruby_object_from_instance(gpointer instance);
 extern VALUE rbgobj_ruby_object_from_instance2(gpointer instance, gboolean alloc);
 extern VALUE rbgobj_ruby_object_from_instance_with_unref(gpointer instance);
+extern void rbgobj_instance_unref(gpointer instance);
 
 extern void rbgobj_add_relative(VALUE obj, VALUE relative);
 extern void rbgobj_invalidate_relatives(VALUE obj);
@@ -171,14 +177,16 @@ extern const RGObjClassInfo *rbgobj_lookup_class_by_gtype_full(GType gtype,
 							       gboolean create_object);
 extern VALUE rbgobj_gtype_to_ruby_class(GType gtype);
 extern VALUE rbgobj_define_class(GType gtype, const gchar* name, VALUE module,
-                                 void* mark, void* free, VALUE parent); 
+                                 RGMarkFunc mark, RGFreeFunc free, VALUE parent); 
 extern VALUE rbgobj_define_class_dynamic(const gchar* gtype_name, 
                                          const gchar* name, VALUE module, 
-                                         void* mark, void* free); 
+                                         RGMarkFunc mark, RGFreeFunc free); 
 extern void rbgobj_register_class(VALUE klass,
                                   GType gtype,
                                   gboolean klass2gtype,
                                   gboolean gtype2klass);
+extern void rbgobj_register_mark_func(GType gtype, RGMarkFunc mark);
+extern void rbgobj_register_free_func(GType gtype, RGFreeFunc free);
 extern VALUE rbgobj_cType;
 extern VALUE rbgobj_gtype_new(GType gtype);
 extern GType rbgobj_gtype_get(VALUE obj);
@@ -225,8 +233,13 @@ extern void rbgobj_register_property_getter(GType gtype, const char* prop_name,
 /* rbgobj_boxed.c */
 extern VALUE rbgobj_boxed_create(VALUE klass); /* deprecated */
 extern gpointer rbgobj_boxed_get(VALUE obj, GType gtype);
+extern gpointer rbgobj_boxed_get_default(VALUE obj, GType gtype);
 extern VALUE rbgobj_make_boxed(gpointer data, GType gtype);
+extern VALUE rbgobj_make_boxed_raw(gpointer p, GType gtype,
+                                   VALUE klass, gint flags);
+extern VALUE rbgobj_make_boxed_default(gpointer data, GType gtype);
 extern void rbgobj_boxed_not_copy_obj(GType gtype);
+extern void rbgobj_boxed_unown(VALUE boxed);
 
 /* rbgobj_enums.c */
 extern void rbgobj_constant_remap(const char *original, const char *replacement);
@@ -265,17 +278,19 @@ extern GType g_poll_fd_get_type(void);
 typedef struct {
     GType type;
     VALUE klass;
-    VALUE (*get_superclass)(void);
-    void (*type_init_hook)(VALUE);
-    void (*rvalue2gvalue)(VALUE val, GValue *result);
-    VALUE (*gvalue2rvalue)(const GValue *);
-    void (*initialize)(VALUE, gpointer);
-    gpointer (*robj2instance)(VALUE);
-    VALUE (*instance2robj)(gpointer);
-    void (*unref)(gpointer instance);
+    gpointer user_data;
+    GDestroyNotify notify;
+    VALUE (*get_superclass)(gpointer user_data);
+    void (*type_init_hook)(VALUE klass, gpointer user_data);
+    void (*rvalue2gvalue)(VALUE value, GValue *result, gpointer user_data);
+    VALUE (*gvalue2rvalue)(const GValue *value, gpointer user_data);
+    void (*initialize)(VALUE rb_instance, gpointer insntance, gpointer user_data);
+    gpointer (*robj2instance)(VALUE rb_instance, gpointer user_data);
+    VALUE (*instance2robj)(gpointer instance, gpointer user_data);
+    void (*unref)(gpointer instance, gpointer user_data);
 } RGConvertTable;
 
-extern void rbgobj_convert_define(RGConvertTable *table);
+extern void rbgobj_convert_define(const RGConvertTable *table);
 
 #ifdef __cplusplus
 }
