@@ -44,7 +44,7 @@ end
 
 rcairo_options = {}
 rcairo_source_dir_names = ["rcairo"]
-if /mingw|cygwin|mswin32/ =~ RUBY_PLATFORM
+if /mingw|cygwin|mswin/ =~ RUBY_PLATFORM
   rcairo_source_dir_names.unshift("rcairo.win32")
 end
 rcairo_source_dir_names.each do |rcairo_source_dir_name|
@@ -54,12 +54,20 @@ rcairo_source_dir_names.each do |rcairo_source_dir_name|
     break
   end
 end
-check_cairo(rcairo_options)
+
+unless check_cairo(rcairo_options)
+  exit(false)
+end
 
 setup_win32(module_name, base_dir)
 
-PKGConfig.have_package('gthread-2.0')
-PKGConfig.have_package(package_id) or exit 1
+unless required_pkg_config_package([package_id, 2, 10, 0],
+                                   :debian => "libgtk2.0-dev",
+                                   :redhat => "gtk2-devel",
+                                   :homebrew => "gtk+",
+                                   :macports => "gtk2")
+  exit(false)
+end
 
 have_header("st.h")
 have_header("ruby/st.h")
