@@ -47,14 +47,14 @@ gtk_allocation_get_type(void)
 static VALUE
 rg_initialize(VALUE self, VALUE x, VALUE y, VALUE width, VALUE height)
 {
-    GtkAllocation new;
+    GtkAllocation allocation;
 
-    new.x = NUM2INT(x);
-    new.y = NUM2INT(y);
-    new.width = NUM2INT(width);
-    new.height = NUM2INT(height);
+    allocation.x = NUM2INT(x);
+    allocation.y = NUM2INT(y);
+    allocation.width = NUM2INT(width);
+    allocation.height = NUM2INT(height);
 
-    G_INITIALIZE(self, &new);
+    G_INITIALIZE(self, g_boxed_copy(GTK_TYPE_ALLOCATION, &allocation));
     return Qnil;
 }
 
@@ -147,7 +147,6 @@ Init_gtk_allocation(VALUE mGtk)
     VALUE RG_TARGET_NAMESPACE;
 
     RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_ALLOCATION, "Allocation", mGtk);
-    rbgobj_boxed_not_copy_obj(GTK_TYPE_ALLOCATION);
 
     RG_DEF_METHOD(initialize, 4);
     RG_DEF_METHOD(intersect, 1);
