@@ -133,14 +133,12 @@ rg_queue_resize(VALUE self)
     return self;
 }
 
-#if GTK_CHECK_VERSION(2,4,0)
 static VALUE
 rg_queue_resize_no_redraw(VALUE self)
 {
     gtk_widget_queue_resize_no_redraw(_SELF(self));
     return self;
 }
-#endif
 
 /* Note this method is not
    gtk_widget_get_size_request */
@@ -203,13 +201,11 @@ rg_accel_closures(VALUE self)
     return GLIST2ARY2F(gtk_widget_list_accel_closures(_SELF(self)), G_TYPE_CLOSURE);
 }
 
-#if GTK_CHECK_VERSION(2,4,0)
 static VALUE
 rg_can_activate_accel_p(VALUE self, VALUE signal_id)
 {
     return CBOOL2RVAL(gtk_widget_can_activate_accel(_SELF(self), NUM2UINT(signal_id)));
 }
-#endif
 
 static VALUE
 rg_event(VALUE self, VALUE event)
@@ -431,7 +427,6 @@ rg_shape_combine_mask(VALUE self, VALUE shape_mask, VALUE offset_x, VALUE offset
     return self;
 }
 
-#if GTK_CHECK_VERSION(2,10,0)
 static VALUE
 rg_input_shape_combine_mask(VALUE self, VALUE shape_mask, VALUE offset_x, VALUE offset_y)
 {
@@ -441,7 +436,6 @@ rg_input_shape_combine_mask(VALUE self, VALUE shape_mask, VALUE offset_x, VALUE
                                         NUM2INT(offset_y));
     return self;
 }
-#endif
 
 static VALUE
 rg_path(VALUE self)
@@ -681,7 +675,6 @@ rg_s_install_style_property(VALUE self, VALUE spec)
     return self;
 }
 
-#if GTK_CHECK_VERSION(2,2,0)
 static VALUE
 rg_s_style_property(VALUE self, VALUE property_name)
 {
@@ -735,7 +728,6 @@ rg_s_style_properties(int argc, VALUE *argv, VALUE self)
     g_type_class_unref(oclass);
     return ary;
 }
-#endif
 
 static VALUE
 rg_region_intersect(VALUE self, VALUE region)
@@ -771,9 +763,8 @@ rg_style_get_property(VALUE self, VALUE prop_name)
     } else {
         name = RVAL2CSTR(prop_name);
     }
-#if GTK_CHECK_VERSION(2,2,0)
     pspec = gtk_widget_class_find_style_property((GtkWidgetClass*)g_type_class_ref(RVAL2GTYPE(self)), name);
-#endif
+
     if (!pspec)
         rb_raise(rb_eval_string("GLib::NoPropertyError"), "No such property: %s", name);
     else {
@@ -841,7 +832,6 @@ rg_settings(VALUE self)
     return GOBJ2RVAL(gtk_widget_get_settings(_SELF(self)));
 }
 
-#if GTK_CHECK_VERSION(2,2,0)
 static VALUE
 rg_get_clipboard(VALUE self, VALUE selection)
 {
@@ -871,7 +861,6 @@ rg_has_screen_p(VALUE self)
 {
     return CBOOL2RVAL(gtk_widget_has_screen(_SELF(self)));
 }
-#endif
 
 /*
   Note this method is not gtk_widget_size_request()
@@ -905,8 +894,6 @@ rg_thaw_child_notify(VALUE self)
     return self;
 }
 
-#if GTK_CHECK_VERSION(2,4,0)
-
 static VALUE
 rg_mnemonic_labels(VALUE self)
 {
@@ -926,7 +913,6 @@ rg_remove_mnemonic_label(VALUE self, VALUE label)
     gtk_widget_remove_mnemonic_label(_SELF(self), GTK_WIDGET(RVAL2GOBJ(label)));
     return self;
 }
-#endif
 
 #if GTK_CHECK_VERSION(2,12,0)
 static VALUE
@@ -951,7 +937,6 @@ rg_trigger_tooltip_query(VALUE self)
 
 #endif
 
-#if GTK_CHECK_VERSION(2,10,0)
 static VALUE
 rg_action(VALUE self)
 {
@@ -963,7 +948,12 @@ rg_composited_p(VALUE self)
 {
     return CBOOL2RVAL(gtk_widget_is_composited(_SELF(self)));
 }
-#endif
+
+static VALUE
+rg_window(VALUE self)
+{
+    return GOBJ2RVAL(_SELF(self)->window);
+}
 
 static VALUE
 rg_set_window(VALUE self, VALUE window)
@@ -1078,9 +1068,7 @@ Init_gtk_widget(VALUE mGtk)
     RG_DEF_METHOD(unrealize, 0);
     RG_DEF_METHOD(queue_draw, 0);
     RG_DEF_METHOD(queue_resize, 0);
-#if GTK_CHECK_VERSION(2,4,0)
     RG_DEF_METHOD(queue_resize_no_redraw, 0);
-#endif
     RG_DEF_METHOD(size_request, 0);
     RG_DEF_METHOD(child_requisition, 0);
     RG_DEF_METHOD(size_allocate, 1);
@@ -1088,17 +1076,13 @@ Init_gtk_widget(VALUE mGtk)
     RG_DEF_METHOD(remove_accelerator, 3);
     RG_DEF_METHOD(set_accel_path, 2);
     RG_DEF_METHOD(accel_closures, 0);
-#if GTK_CHECK_VERSION(2,4,0)
     RG_DEF_METHOD_P(can_activate_accel, 1);
-#endif
     RG_DEF_METHOD(event, 1);
     RG_DEF_METHOD(activate, 0);
     RG_DEF_METHOD(reparent, 1);
     RG_DEF_SMETHOD(install_style_property, 1);
-#if GTK_CHECK_VERSION(2,2,0)
     RG_DEF_SMETHOD(style_property, 1);
     RG_DEF_SMETHOD(style_properties, -1);
-#endif
     RG_DEF_METHOD(intersect, 1);
     RG_DEF_METHOD(grab_default, 0);
     RG_DEF_METHOD(set_state, 1);
@@ -1119,9 +1103,7 @@ Init_gtk_widget(VALUE mGtk)
     RG_DEF_METHOD(set_direction, 1);
     RG_DEF_METHOD(direction, 0);
     RG_DEF_METHOD(shape_combine_mask, 3);
-#if GTK_CHECK_VERSION(2,10,0)
     RG_DEF_METHOD(input_shape_combine_mask, 3);
-#endif
     RG_DEF_METHOD(path, 0);
     RG_DEF_METHOD(class_path, 0);
     RG_DEF_METHOD(composite_name, 0);
@@ -1160,31 +1142,26 @@ Init_gtk_widget(VALUE mGtk)
     RG_DEF_METHOD(freeze_child_notify, 0);
     RG_DEF_METHOD_P(child_visible, 0);
     RG_DEF_METHOD(settings, 0);
-#if GTK_CHECK_VERSION(2,2,0)
     RG_DEF_METHOD(get_clipboard, 1);
     RG_DEF_METHOD(display, 0);
     RG_DEF_METHOD(root_window, 0);
     RG_DEF_METHOD(screen, 0);
     RG_DEF_METHOD_P(has_screen, 0);
-#endif
     RG_DEF_METHOD(set_child_visible, 1);
     RG_DEF_METHOD(get_size_request, 0);
     RG_DEF_METHOD(set_size_request, 2);
     RG_DEF_METHOD(thaw_child_notify, 0);
-#if GTK_CHECK_VERSION(2,4,0)
     RG_DEF_METHOD(mnemonic_labels, 0);
     RG_DEF_METHOD(add_mnemonic_label, 1);
     RG_DEF_METHOD(remove_mnemonic_label, 1);
-#endif
 #if GTK_CHECK_VERSION(2,12,0)
     RG_DEF_METHOD(set_tooltip_window, 1);
     RG_DEF_METHOD(tooltip_window, 0);
     RG_DEF_METHOD(trigger_tooltip_query, 0);
 #endif
-#if GTK_CHECK_VERSION(2,10,0)
     RG_DEF_METHOD(action, 0);
     RG_DEF_METHOD_P(composited, 0);
-#endif
+    RG_DEF_METHOD(window, 0);
     RG_DEF_METHOD(set_window, 1);
     RG_DEF_METHOD(allocation, 0);
     RG_DEF_METHOD(set_allocation, 4);
