@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2011-2013  Ruby-GNOME2 Project Team
  *  Copyright (C) 2002-2005 Masao Mutoh
  *
  *  This library is free software; you can redistribute it and/or
@@ -71,13 +71,11 @@ rg_families(VALUE self)
     return result;
 }
 
-#if PANGO_CHECK_VERSION(1,4,0)
 static VALUE
 rg_shape_engine_type(VALUE self)
 {
     return CSTR2RVAL(pango_font_map_get_shape_engine_type(_SELF(self)));
 }
-#endif
 
 void
 Init_pango_font_map(VALUE mPango)
@@ -90,18 +88,15 @@ Init_pango_font_map(VALUE mPango)
     RG_DEF_METHOD(load_font, 2);
     RG_DEF_METHOD(load_fontset, 3);
     RG_DEF_METHOD(families, 0);
-#if PANGO_CHECK_VERSION(1,4,0)
     RG_DEF_METHOD(shape_engine_type, 0);
-#endif
 
     G_DEF_CLASS3("PangoFcFontMap", "FcFontMap", mPango);
     G_DEF_CLASS3("PangoXftFontMap", "XftFontMap", mPango);
     G_DEF_CLASS3("PangoFT2FontMap", "FT2FontMap", mPango);
     G_DEF_CLASS3("PangoXFontMap", "XFontMap", mPango);
     G_DEF_CLASS3("PangoWin32FontMap", "Win32FontMap", mPango);
+    G_DEF_CLASS3("PangoCoreTextFontMap", "CoreTextFontMap", mPango);
     G_DEF_CLASS3("PangoCairoFcFontMap", "CairoFcFontMap", mPango);
     G_DEF_CLASS3("PangoCairoWin32FontMap", "CairoWin32FontMap", mPango);
-#if PANGO_CHECK_VERSION(1,12,0)
-    G_DEF_CLASS3("PangoATSUIFontMap", "ATSUIFontMap", mPango);
-#endif
+    G_DEF_CLASS3("PangoCairoCoreTextFontMap", "CairoCoreTextFontMap", mPango);
 }
