@@ -1,49 +1,10 @@
 class TestPage < Test::Unit::TestCase
   def test_get_image
+    omit("We don't have PDF that has image...")
     document = Poppler::Document.new(image_pdf)
     page, mapping = find_first_image_mapping(document)
-    if later_version?(0, 7, 2) and Poppler.cairo_available?
-      assert_kind_of(Cairo::ImageSurface, page.get_image(mapping.image_id))
-      assert_kind_of(Cairo::ImageSurface, mapping.image)
-    else
-      assert_kind_of(Gdk::Pixbuf, mapping.image)
-    end
-  end
-
-  def test_render_to_pixbuf
-    only_old_poppler_version(0, 17, 0)
-
-    document = Poppler::Document.new(image_pdf)
-    page = document[0]
-    width, height = page.size
-    pixbuf = Gdk::Pixbuf.new(Gdk::Pixbuf::COLORSPACE_RGB, true, 8,
-                             width / 2, height / 2)
-    pixbuf.fill!(0)
-    assert_equal("\0" * 10, pixbuf.pixels[0, 10])
-    page.render(0, 0, width, height, 0.5, 0, pixbuf)
-    assert_not_equal("\0" * 10, pixbuf.pixels[0, 10])
-  end
-
-  def test_render_to_pixbuf_for_printing
-    only_poppler_version(0, 7, 2)
-    only_old_poppler_version(0, 17, 0)
-
-    document = Poppler::Document.new(image_pdf)
-    page = document[0]
-    width, height = page.size
-    pixbuf = Gdk::Pixbuf.new(Gdk::Pixbuf::COLORSPACE_RGB, true, 8,
-                             width / 2, height / 2)
-    pixbuf.fill!(0)
-    assert_equal("\0" * 10, pixbuf.pixels[0, 10])
-    page.render_for_printing(0, 0, width, height, 0.5, 0, pixbuf)
-    assert_not_equal("\0" * 10, pixbuf.pixels[0, 10])
-  end
-
-  def test_thumbnail_pixbuf
-    omit("We doesn't have a PDF that has a thumbnail...")
-    document = Poppler::Document.new(thumbnail_pdf)
-    page = document[0]
-    assert_kind_of(Gdk::Pixbuf, page.thumbnail_pixbuf)
+    assert_kind_of(Cairo::ImageSurface, page.get_image(mapping.image_id))
+    assert_kind_of(Cairo::ImageSurface, mapping.image)
   end
 
   def test_selection_region
@@ -69,6 +30,24 @@ class TestPage < Test::Unit::TestCase
     assert_kind_of(Poppler::Annotation, mapping.annotation)
   end
 
+  def test_render
+    only_poppler_version(0, 20, 0)
+    document = Poppler::Document.new(image_pdf)
+    page = document[0]
+    png = StringIO.new
+    png.set_encoding("ASCII-8BIT")
+    Cairo::ImageSurface.new(:argb32, *page.size) do |surface|
+      Cairo::Context.new(surface) do |context|
+        page.render(context)
+      end
+      surface.write_to_png(png)
+    end
+    File.open(image_png, "rb") do |image|
+      # TODO: support image diff
+      assert_equal(image.read, png.string)
+    end
+  end
+
   private
   def find_first_image_mapping(document)
     document.each do |page|
