@@ -27,16 +27,27 @@ Pathname.glob((base_dir + "*").to_s) do |dir|
   targets << dir
 end
 
+ignored_modules = [
+  "gstreamer",
+  "gstreamer-no-gi",
+  "webkit-gtk",
+  "webkit-gtk2",
+]
+
+succeeded = true
 targets.each do |target|
+  next if ignored_modules.include?(target.basename.to_s)
   Dir.chdir(target.to_s) do
     puts "#{Time.now} running test for #{target}"
     puts separator
 
     args = includes + ["test/run-test.rb"]
     command = [ruby, *args]
-    system(command.collect {|arg| "'#{arg.gsub(/'/, '\\\'')}'"}.join(' '))
+    unless system(command.collect {|arg| "'#{arg.gsub(/'/, '\\\'')}'"}.join(' '))
+      succeeded = false
+    end
 
     puts separator
   end
 end
-
+exit(succeeded)
