@@ -93,56 +93,6 @@ rg_initialize(VALUE self)
 }
 
 #if VTE_CHECK_VERSION(0, 26, 0)
-static const char *
-rb_grn_inspect (VALUE object)
-{
-    VALUE inspected;
-
-    inspected = rb_funcall(object, rb_intern("inspect"), 0);
-    return StringValueCStr(inspected);
-}
-
-
-static void
-rb_grn_scan_options (VALUE options, ...)
-{
-    VALUE original_options = options;
-    VALUE available_keys;
-    const char *key;
-    VALUE *value;
-    va_list args;
-
-    options = rb_check_convert_type(options, T_HASH, "Hash", "to_hash");
-    if (NIL_P(options)) {
-        options = rb_hash_new();
-    } else if (options == original_options) {
-        options = rb_funcall(options, rb_intern("dup"), 0);
-    }
-
-    available_keys = rb_ary_new();
-    va_start(args, options);
-    key = va_arg(args, const char *);
-    while (key) {
-        VALUE rb_key;
-        value = va_arg(args, VALUE *);
-
-        rb_key = ID2SYM(rb_intern(key));
-        rb_ary_push(available_keys, rb_key);
-        *value = rb_funcall(options, rb_intern("delete"), 1, rb_key);
-
-        key = va_arg(args, const char *);
-    }
-    va_end(args);
-
-    if (RVAL2CBOOL(rb_funcall(options, rb_intern("empty?"), 0)))
-        return;
-
-    rb_raise(rb_eArgError,
-             "unexpected key(s) exist: %s: available keys: %s",
-             rb_grn_inspect(rb_funcall(options, rb_intern("keys"), 0)),
-             rb_grn_inspect(available_keys));
-}
-
 static VALUE
 fork_command_default_argv(void)
 {
@@ -171,13 +121,13 @@ fork_command_full(int argc, VALUE *argv, VALUE self)
     GError *error = NULL;
 
     rb_scan_args(argc, argv, "01", &options);
-    rb_grn_scan_options(options,
-                        "pty_flags", &rb_pty_flags,
-                        "working_directory", &rb_working_directory,
-                        "argv", &rb_command_argv,
-                        "envv", &rb_envv,
-                        "spawn_flags", &rb_spawn_flags,
-                        NULL);
+    rbg_scan_options(options,
+                     "pty_flags", &rb_pty_flags,
+                     "working_directory", &rb_working_directory,
+                     "argv", &rb_command_argv,
+                     "envv", &rb_envv,
+                     "spawn_flags", &rb_spawn_flags,
+                     NULL);
     pty_flags = NIL_P(rb_pty_flags) ?
                 VTE_PTY_DEFAULT :
                 RVAL2GFLAGS(rb_pty_flags, VTE_TYPE_PTY_FLAGS);
@@ -1107,7 +1057,9 @@ Init_vte_terminal(VALUE mVte)
 #if VTE_CHECK_VERSION(0, 19, 1)
     G_DEF_CLASS(VTE_TYPE_TERMINAL_CURSOR_SHAPE, "CursorShape", RG_TARGET_NAMESPACE);
 #endif
+#if VTE_CHECK_VERSION(0, 24, 0)
     G_DEF_CLASS(VTE_TYPE_TERMINAL_WRITE_FLAGS, "WriteFlags", RG_TARGET_NAMESPACE);
+#endif
 
     RG_DEF_METHOD(initialize, 0);
 
